// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: opentelemetry/proto/trace/v1/trace.proto
// Protobuf C++ Version: 7.35.1

#ifndef opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto_2epb_2eh
#define opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
#include "opentelemetry/proto/common/v1/common.pb.h"
#include "opentelemetry/proto/resource/v1/resource.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
}  // extern "C"
namespace opentelemetry {
namespace proto {
namespace trace {
namespace v1 {
enum Span_SpanKind : int;
extern const uint32_t Span_SpanKind_internal_data_[];
enum Status_StatusCode : int;
extern const uint32_t Status_StatusCode_internal_data_[];
class ResourceSpans;
struct ResourceSpansGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern ResourceSpansGlobalsTypeInternal ResourceSpans_globals_;
extern const ::google::protobuf::internal::ClassDataFull ResourceSpans_class_data_;
#else
extern const ResourceSpansGlobalsTypeInternal ResourceSpans_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class ScopeSpans;
struct ScopeSpansGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern ScopeSpansGlobalsTypeInternal ScopeSpans_globals_;
extern const ::google::protobuf::internal::ClassDataFull ScopeSpans_class_data_;
#else
extern const ScopeSpansGlobalsTypeInternal ScopeSpans_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class Span;
struct SpanGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern SpanGlobalsTypeInternal Span_globals_;
extern const ::google::protobuf::internal::ClassDataFull Span_class_data_;
#else
extern const SpanGlobalsTypeInternal Span_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class Span_Event;
struct Span_EventGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern Span_EventGlobalsTypeInternal Span_Event_globals_;
extern const ::google::protobuf::internal::ClassDataFull Span_Event_class_data_;
#else
extern const Span_EventGlobalsTypeInternal Span_Event_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class Span_Link;
struct Span_LinkGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern Span_LinkGlobalsTypeInternal Span_Link_globals_;
extern const ::google::protobuf::internal::ClassDataFull Span_Link_class_data_;
#else
extern const Span_LinkGlobalsTypeInternal Span_Link_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class Status;
struct StatusGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern StatusGlobalsTypeInternal Status_globals_;
extern const ::google::protobuf::internal::ClassDataFull Status_class_data_;
#else
extern const StatusGlobalsTypeInternal Status_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class TracesData;
struct TracesDataGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern TracesDataGlobalsTypeInternal TracesData_globals_;
extern const ::google::protobuf::internal::ClassDataFull TracesData_class_data_;
#else
extern const TracesDataGlobalsTypeInternal TracesData_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
}  // namespace v1
}  // namespace trace
}  // namespace proto
}  // namespace opentelemetry
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::opentelemetry::proto::trace::v1::Span_SpanKind_internal_data_>
    internal::EnumTraitsImpl::value<::opentelemetry::proto::trace::v1::Span_SpanKind>;
template <>
internal::EnumTraitsT<::opentelemetry::proto::trace::v1::Status_StatusCode_internal_data_>
    internal::EnumTraitsImpl::value<::opentelemetry::proto::trace::v1::Status_StatusCode>;
}  // namespace protobuf
}  // namespace google

namespace opentelemetry {
namespace proto {
namespace trace {
namespace v1 {
enum Span_SpanKind : int {
  Span_SpanKind_SPAN_KIND_UNSPECIFIED = 0,
  Span_SpanKind_SPAN_KIND_INTERNAL = 1,
  Span_SpanKind_SPAN_KIND_SERVER = 2,
  Span_SpanKind_SPAN_KIND_CLIENT = 3,
  Span_SpanKind_SPAN_KIND_PRODUCER = 4,
  Span_SpanKind_SPAN_KIND_CONSUMER = 5,
  Span_SpanKind_Span_SpanKind_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  Span_SpanKind_Span_SpanKind_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t Span_SpanKind_internal_data_[];
inline constexpr Span_SpanKind Span_SpanKind_SpanKind_MIN =
    static_cast<Span_SpanKind>(0);
inline constexpr Span_SpanKind Span_SpanKind_SpanKind_MAX =
    static_cast<Span_SpanKind>(5);
[[nodiscard]] inline bool Span_SpanKind_IsValid(int value) {
  return 0 <= value && value <= 5;
}
inline constexpr int Span_SpanKind_SpanKind_ARRAYSIZE = 5 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
Span_SpanKind_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(Span_SpanKind) {
  return Span_SpanKind_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& Span_SpanKind_Name(T value) {
  static_assert(::std::is_same<T, Span_SpanKind>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to SpanKind_Name().");
  return Span_SpanKind_Name(static_cast<Span_SpanKind>(value));
}
template <>
[[nodiscard]] inline const ::std::string& Span_SpanKind_Name(Span_SpanKind value) {
  return ::google::protobuf::internal::NameOfDenseEnum<Span_SpanKind_descriptor, 0, 5>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool Span_SpanKind_Parse(
    ::absl::string_view name, Span_SpanKind* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<Span_SpanKind>(Span_SpanKind_descriptor(), name,
                                           value);
}
enum Status_StatusCode : int {
  Status_StatusCode_STATUS_CODE_UNSET = 0,
  Status_StatusCode_STATUS_CODE_OK = 1,
  Status_StatusCode_STATUS_CODE_ERROR = 2,
  Status_StatusCode_Status_StatusCode_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  Status_StatusCode_Status_StatusCode_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t Status_StatusCode_internal_data_[];
inline constexpr Status_StatusCode Status_StatusCode_StatusCode_MIN =
    static_cast<Status_StatusCode>(0);
inline constexpr Status_StatusCode Status_StatusCode_StatusCode_MAX =
    static_cast<Status_StatusCode>(2);
[[nodiscard]] inline bool Status_StatusCode_IsValid(int value) {
  return 0 <= value && value <= 2;
}
inline constexpr int Status_StatusCode_StatusCode_ARRAYSIZE = 2 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
Status_StatusCode_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(Status_StatusCode) {
  return Status_StatusCode_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& Status_StatusCode_Name(T value) {
  static_assert(::std::is_same<T, Status_StatusCode>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to StatusCode_Name().");
  return Status_StatusCode_Name(static_cast<Status_StatusCode>(value));
}
template <>
[[nodiscard]] inline const ::std::string& Status_StatusCode_Name(Status_StatusCode value) {
  return ::google::protobuf::internal::NameOfDenseEnum<Status_StatusCode_descriptor, 0, 2>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool Status_StatusCode_Parse(
    ::absl::string_view name, Status_StatusCode* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<Status_StatusCode>(Status_StatusCode_descriptor(), name,
                                           value);
}
using ::google::protobuf::internal::generated_enum::AbslParseFlag;
using ::google::protobuf::internal::generated_enum::AbslUnparseFlag;

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Status final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.Status) */ {
 public:
  inline Status() : Status(nullptr) {}
  ~Status() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Status* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Status));
  }
#endif

  template <typename = void>
  explicit constexpr Status(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Status(const Status& from) : Status(nullptr, from) {}
  inline Status(Status&& from) noexcept : Status(nullptr, ::std::move(from)) {}
  inline Status& operator=(const Status& from) {
    CopyFrom(from);
    return *this;
  }
  inline Status& operator=(Status&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Status& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Status>(&Status_globals_);
  }
  static constexpr int kIndexInFileMessages = 6;
  friend void swap(Status& a, Status& b) { a.Swap(&b); }
  inline void Swap(Status* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Status* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Status* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Status>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Status& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Status& from) { Status::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Status* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.Status"; }

  explicit Status(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Status(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Status& from);
  Status(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Status&& from) noexcept
      : Status(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using StatusCode = Status_StatusCode;
  static constexpr StatusCode STATUS_CODE_UNSET = Status_StatusCode_STATUS_CODE_UNSET;
  static constexpr StatusCode STATUS_CODE_OK = Status_StatusCode_STATUS_CODE_OK;
  static constexpr StatusCode STATUS_CODE_ERROR = Status_StatusCode_STATUS_CODE_ERROR;
  [[nodiscard]] static inline bool StatusCode_IsValid(int value) {
    return Status_StatusCode_IsValid(value);
  }
  static constexpr StatusCode StatusCode_MIN = Status_StatusCode_StatusCode_MIN;
  static constexpr StatusCode StatusCode_MAX = Status_StatusCode_StatusCode_MAX;
  static constexpr int StatusCode_ARRAYSIZE = Status_StatusCode_StatusCode_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL StatusCode_descriptor() {
    return Status_StatusCode_descriptor();
  }
  template <typename T>
  [[nodiscard]] static inline const ::std::string& StatusCode_Name(T value) {
    return Status_StatusCode_Name(value);
  }
  [[nodiscard]] static inline bool StatusCode_Parse(
      ::absl::string_view name, StatusCode* PROTOBUF_NONNULL value) {
    return Status_StatusCode_Parse(name, value);
  }

  // accessors -------------------------------------------------------
  enum : int {
    kMessageFieldNumber = 2,
    kCodeFieldNumber = 3,
  };
  // string message = 2;
  void clear_message() ;
  [[nodiscard]] const ::std::string& message() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_message(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_message();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_message();
  void set_allocated_message(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_message() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_message(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_message();

  public:
  // .opentelemetry.proto.trace.v1.Status.StatusCode code = 3;
  void clear_code() ;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::Status_StatusCode code() const;
  void set_code(::opentelemetry::proto::trace::v1::Status_StatusCode value);

  private:
  ::opentelemetry::proto::trace::v1::Status_StatusCode _internal_code() const;
  void _internal_set_code(::opentelemetry::proto::trace::v1::Status_StatusCode value);

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.Status)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<1, 2,
                          0, 51,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Status& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr message_;
    int code_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Span_Link final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.Span.Link) */ {
 public:
  inline Span_Link() : Span_Link(nullptr) {}
  ~Span_Link() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Span_Link* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Span_Link));
  }
#endif

  template <typename = void>
  explicit constexpr Span_Link(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Span_Link(const Span_Link& from) : Span_Link(nullptr, from) {}
  inline Span_Link(Span_Link&& from) noexcept : Span_Link(nullptr, ::std::move(from)) {}
  inline Span_Link& operator=(const Span_Link& from) {
    CopyFrom(from);
    return *this;
  }
  inline Span_Link& operator=(Span_Link&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Span_Link& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Span_Link>(&Span_Link_globals_);
  }
  static constexpr int kIndexInFileMessages = 4;
  friend void swap(Span_Link& a, Span_Link& b) { a.Swap(&b); }
  inline void Swap(Span_Link* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Span_Link* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Span_Link* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Span_Link>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Span_Link& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Span_Link& from) { Span_Link::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Span_Link* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.Span.Link"; }

  explicit Span_Link(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Span_Link(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Span_Link& from);
  Span_Link(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Span_Link&& from) noexcept
      : Span_Link(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kAttributesFieldNumber = 4,
    kTraceIdFieldNumber = 1,
    kSpanIdFieldNumber = 2,
    kTraceStateFieldNumber = 3,
    kDroppedAttributesCountFieldNumber = 5,
  };
  // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 4;
  [[nodiscard]] int attributes_size()
      const;
  private:
  int _internal_attributes_size() const;

  public:
  void clear_attributes() ;
  [[nodiscard]] const ::opentelemetry::proto::common::v1::KeyValue& attributes(int index) const;
  [[nodiscard]] ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL mutable_attributes(int index);
  ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL add_attributes();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>&
  attributes() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
  mutable_attributes();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>& _internal_attributes() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL _internal_mutable_attributes();

  public:
  // bytes trace_id = 1;
  void clear_trace_id() ;
  [[nodiscard]] const ::std::string& trace_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_trace_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_trace_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_trace_id();
  void set_allocated_trace_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_trace_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_trace_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_trace_id();

  public:
  // bytes span_id = 2;
  void clear_span_id() ;
  [[nodiscard]] const ::std::string& span_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_span_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_span_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_span_id();
  void set_allocated_span_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_span_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_span_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_span_id();

  public:
  // string trace_state = 3;
  void clear_trace_state() ;
  [[nodiscard]] const ::std::string& trace_state() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_trace_state(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_trace_state();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_trace_state();
  void set_allocated_trace_state(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_trace_state() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_trace_state(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_trace_state();

  public:
  // uint32 dropped_attributes_count = 5;
  void clear_dropped_attributes_count() ;
  [[nodiscard]] ::uint32_t dropped_attributes_count() const;
  void set_dropped_attributes_count(::uint32_t value);

  private:
  ::uint32_t _internal_dropped_attributes_count() const;
  void _internal_set_dropped_attributes_count(::uint32_t value);

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.Span.Link)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 5,
                          1, 58,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Span_Link& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::common::v1::KeyValue > attributes_;
    ::google::protobuf::internal::ArenaStringPtr trace_id_;
    ::google::protobuf::internal::ArenaStringPtr span_id_;
    ::google::protobuf::internal::ArenaStringPtr trace_state_;
    ::uint32_t dropped_attributes_count_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Span_Event final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.Span.Event) */ {
 public:
  inline Span_Event() : Span_Event(nullptr) {}
  ~Span_Event() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Span_Event* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Span_Event));
  }
#endif

  template <typename = void>
  explicit constexpr Span_Event(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Span_Event(const Span_Event& from) : Span_Event(nullptr, from) {}
  inline Span_Event(Span_Event&& from) noexcept : Span_Event(nullptr, ::std::move(from)) {}
  inline Span_Event& operator=(const Span_Event& from) {
    CopyFrom(from);
    return *this;
  }
  inline Span_Event& operator=(Span_Event&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Span_Event& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Span_Event>(&Span_Event_globals_);
  }
  static constexpr int kIndexInFileMessages = 3;
  friend void swap(Span_Event& a, Span_Event& b) { a.Swap(&b); }
  inline void Swap(Span_Event* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Span_Event* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Span_Event* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Span_Event>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Span_Event& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Span_Event& from) { Span_Event::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Span_Event* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.Span.Event"; }

  explicit Span_Event(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Span_Event(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Span_Event& from);
  Span_Event(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Span_Event&& from) noexcept
      : Span_Event(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kAttributesFieldNumber = 3,
    kNameFieldNumber = 2,
    kTimeUnixNanoFieldNumber = 1,
    kDroppedAttributesCountFieldNumber = 4,
  };
  // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 3;
  [[nodiscard]] int attributes_size()
      const;
  private:
  int _internal_attributes_size() const;

  public:
  void clear_attributes() ;
  [[nodiscard]] const ::opentelemetry::proto::common::v1::KeyValue& attributes(int index) const;
  [[nodiscard]] ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL mutable_attributes(int index);
  ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL add_attributes();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>&
  attributes() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
  mutable_attributes();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>& _internal_attributes() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL _internal_mutable_attributes();

  public:
  // string name = 2;
  void clear_name() ;
  [[nodiscard]] const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // fixed64 time_unix_nano = 1;
  void clear_time_unix_nano() ;
  [[nodiscard]] ::uint64_t time_unix_nano() const;
  void set_time_unix_nano(::uint64_t value);

  private:
  ::uint64_t _internal_time_unix_nano() const;
  void _internal_set_time_unix_nano(::uint64_t value);

  public:
  // uint32 dropped_attributes_count = 4;
  void clear_dropped_attributes_count() ;
  [[nodiscard]] ::uint32_t dropped_attributes_count() const;
  void set_dropped_attributes_count(::uint32_t value);

  private:
  ::uint32_t _internal_dropped_attributes_count() const;
  void _internal_set_dropped_attributes_count(::uint32_t value);

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.Span.Event)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 4,
                          1, 52,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Span_Event& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::common::v1::KeyValue > attributes_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    ::uint64_t time_unix_nano_;
    ::uint32_t dropped_attributes_count_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Span final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.Span) */ {
 public:
  inline Span() : Span(nullptr) {}
  ~Span() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Span* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Span));
  }
#endif

  template <typename = void>
  explicit constexpr Span(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Span(const Span& from) : Span(nullptr, from) {}
  inline Span(Span&& from) noexcept : Span(nullptr, ::std::move(from)) {}
  inline Span& operator=(const Span& from) {
    CopyFrom(from);
    return *this;
  }
  inline Span& operator=(Span&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Span& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Span>(&Span_globals_);
  }
  static constexpr int kIndexInFileMessages = 5;
  friend void swap(Span& a, Span& b) { a.Swap(&b); }
  inline void Swap(Span* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Span* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Span* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Span>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Span& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Span& from) { Span::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Span* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.Span"; }

  explicit Span(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Span(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Span& from);
  Span(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Span&& from) noexcept
      : Span(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using Event = Span_Event;
  using Link = Span_Link;
  using SpanKind = Span_SpanKind;
  static constexpr SpanKind SPAN_KIND_UNSPECIFIED = Span_SpanKind_SPAN_KIND_UNSPECIFIED;
  static constexpr SpanKind SPAN_KIND_INTERNAL = Span_SpanKind_SPAN_KIND_INTERNAL;
  static constexpr SpanKind SPAN_KIND_SERVER = Span_SpanKind_SPAN_KIND_SERVER;
  static constexpr SpanKind SPAN_KIND_CLIENT = Span_SpanKind_SPAN_KIND_CLIENT;
  static constexpr SpanKind SPAN_KIND_PRODUCER = Span_SpanKind_SPAN_KIND_PRODUCER;
  static constexpr SpanKind SPAN_KIND_CONSUMER = Span_SpanKind_SPAN_KIND_CONSUMER;
  [[nodiscard]] static inline bool SpanKind_IsValid(int value) {
    return Span_SpanKind_IsValid(value);
  }
  static constexpr SpanKind SpanKind_MIN = Span_SpanKind_SpanKind_MIN;
  static constexpr SpanKind SpanKind_MAX = Span_SpanKind_SpanKind_MAX;
  static constexpr int SpanKind_ARRAYSIZE = Span_SpanKind_SpanKind_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL SpanKind_descriptor() {
    return Span_SpanKind_descriptor();
  }
  template <typename T>
  [[nodiscard]] static inline const ::std::string& SpanKind_Name(T value) {
    return Span_SpanKind_Name(value);
  }
  [[nodiscard]] static inline bool SpanKind_Parse(
      ::absl::string_view name, SpanKind* PROTOBUF_NONNULL value) {
    return Span_SpanKind_Parse(name, value);
  }

  // accessors -------------------------------------------------------
  enum : int {
    kAttributesFieldNumber = 9,
    kEventsFieldNumber = 11,
    kLinksFieldNumber = 13,
    kTraceIdFieldNumber = 1,
    kSpanIdFieldNumber = 2,
    kTraceStateFieldNumber = 3,
    kParentSpanIdFieldNumber = 4,
    kNameFieldNumber = 5,
    kStatusFieldNumber = 15,
    kStartTimeUnixNanoFieldNumber = 7,
    kEndTimeUnixNanoFieldNumber = 8,
    kKindFieldNumber = 6,
    kDroppedAttributesCountFieldNumber = 10,
    kDroppedEventsCountFieldNumber = 12,
    kDroppedLinksCountFieldNumber = 14,
  };
  // repeated .opentelemetry.proto.common.v1.KeyValue attributes = 9;
  [[nodiscard]] int attributes_size()
      const;
  private:
  int _internal_attributes_size() const;

  public:
  void clear_attributes() ;
  [[nodiscard]] const ::opentelemetry::proto::common::v1::KeyValue& attributes(int index) const;
  [[nodiscard]] ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL mutable_attributes(int index);
  ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL add_attributes();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>&
  attributes() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
  mutable_attributes();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>& _internal_attributes() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL _internal_mutable_attributes();

  public:
  // repeated .opentelemetry.proto.trace.v1.Span.Event events = 11;
  [[nodiscard]] int events_size()
      const;
  private:
  int _internal_events_size() const;

  public:
  void clear_events() ;
  [[nodiscard]] const ::opentelemetry::proto::trace::v1::Span_Event& events(int index) const;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::Span_Event* PROTOBUF_NONNULL mutable_events(int index);
  ::opentelemetry::proto::trace::v1::Span_Event* PROTOBUF_NONNULL add_events();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>&
  events() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>* PROTOBUF_NONNULL
  mutable_events();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>& _internal_events() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>* PROTOBUF_NONNULL _internal_mutable_events();

  public:
  // repeated .opentelemetry.proto.trace.v1.Span.Link links = 13;
  [[nodiscard]] int links_size()
      const;
  private:
  int _internal_links_size() const;

  public:
  void clear_links() ;
  [[nodiscard]] const ::opentelemetry::proto::trace::v1::Span_Link& links(int index) const;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::Span_Link* PROTOBUF_NONNULL mutable_links(int index);
  ::opentelemetry::proto::trace::v1::Span_Link* PROTOBUF_NONNULL add_links();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>&
  links() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>* PROTOBUF_NONNULL
  mutable_links();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>& _internal_links() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>* PROTOBUF_NONNULL _internal_mutable_links();

  public:
  // bytes trace_id = 1;
  void clear_trace_id() ;
  [[nodiscard]] const ::std::string& trace_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_trace_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_trace_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_trace_id();
  void set_allocated_trace_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_trace_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_trace_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_trace_id();

  public:
  // bytes span_id = 2;
  void clear_span_id() ;
  [[nodiscard]] const ::std::string& span_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_span_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_span_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_span_id();
  void set_allocated_span_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_span_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_span_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_span_id();

  public:
  // string trace_state = 3;
  void clear_trace_state() ;
  [[nodiscard]] const ::std::string& trace_state() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_trace_state(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_trace_state();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_trace_state();
  void set_allocated_trace_state(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_trace_state() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_trace_state(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_trace_state();

  public:
  // bytes parent_span_id = 4;
  void clear_parent_span_id() ;
  [[nodiscard]] const ::std::string& parent_span_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_parent_span_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_parent_span_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_parent_span_id();
  void set_allocated_parent_span_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_parent_span_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_parent_span_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_parent_span_id();

  public:
  // string name = 5;
  void clear_name() ;
  [[nodiscard]] const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // .opentelemetry.proto.trace.v1.Status status = 15;
  [[nodiscard]] bool has_status()
      const;
  void clear_status() ;
  [[nodiscard]] const ::opentelemetry::proto::trace::v1::Status& status() const;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE release_status();
  ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NONNULL mutable_status();
  void set_allocated_status(::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_status(::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE value);
  ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE unsafe_arena_release_status();

  private:
  const ::opentelemetry::proto::trace::v1::Status& _internal_status() const;
  ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NONNULL _internal_mutable_status();

  public:
  // fixed64 start_time_unix_nano = 7;
  void clear_start_time_unix_nano() ;
  [[nodiscard]] ::uint64_t start_time_unix_nano() const;
  void set_start_time_unix_nano(::uint64_t value);

  private:
  ::uint64_t _internal_start_time_unix_nano() const;
  void _internal_set_start_time_unix_nano(::uint64_t value);

  public:
  // fixed64 end_time_unix_nano = 8;
  void clear_end_time_unix_nano() ;
  [[nodiscard]] ::uint64_t end_time_unix_nano() const;
  void set_end_time_unix_nano(::uint64_t value);

  private:
  ::uint64_t _internal_end_time_unix_nano() const;
  void _internal_set_end_time_unix_nano(::uint64_t value);

  public:
  // .opentelemetry.proto.trace.v1.Span.SpanKind kind = 6;
  void clear_kind() ;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::Span_SpanKind kind() const;
  void set_kind(::opentelemetry::proto::trace::v1::Span_SpanKind value);

  private:
  ::opentelemetry::proto::trace::v1::Span_SpanKind _internal_kind() const;
  void _internal_set_kind(::opentelemetry::proto::trace::v1::Span_SpanKind value);

  public:
  // uint32 dropped_attributes_count = 10;
  void clear_dropped_attributes_count() ;
  [[nodiscard]] ::uint32_t dropped_attributes_count() const;
  void set_dropped_attributes_count(::uint32_t value);

  private:
  ::uint32_t _internal_dropped_attributes_count() const;
  void _internal_set_dropped_attributes_count(::uint32_t value);

  public:
  // uint32 dropped_events_count = 12;
  void clear_dropped_events_count() ;
  [[nodiscard]] ::uint32_t dropped_events_count() const;
  void set_dropped_events_count(::uint32_t value);

  private:
  ::uint32_t _internal_dropped_events_count() const;
  void _internal_set_dropped_events_count(::uint32_t value);

  public:
  // uint32 dropped_links_count = 14;
  void clear_dropped_links_count() ;
  [[nodiscard]] ::uint32_t dropped_links_count() const;
  void set_dropped_links_count(::uint32_t value);

  private:
  ::uint32_t _internal_dropped_links_count() const;
  void _internal_set_dropped_links_count(::uint32_t value);

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.Span)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<4, 15,
                          4, 65,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Span& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::common::v1::KeyValue > attributes_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::trace::v1::Span_Event > events_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::trace::v1::Span_Link > links_;
    ::google::protobuf::internal::ArenaStringPtr trace_id_;
    ::google::protobuf::internal::ArenaStringPtr span_id_;
    ::google::protobuf::internal::ArenaStringPtr trace_state_;
    ::google::protobuf::internal::ArenaStringPtr parent_span_id_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE status_;
    ::uint64_t start_time_unix_nano_;
    ::uint64_t end_time_unix_nano_;
    int kind_;
    ::uint32_t dropped_attributes_count_;
    ::uint32_t dropped_events_count_;
    ::uint32_t dropped_links_count_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ScopeSpans final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.ScopeSpans) */ {
 public:
  inline ScopeSpans() : ScopeSpans(nullptr) {}
  ~ScopeSpans() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ScopeSpans* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ScopeSpans));
  }
#endif

  template <typename = void>
  explicit constexpr ScopeSpans(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline ScopeSpans(const ScopeSpans& from) : ScopeSpans(nullptr, from) {}
  inline ScopeSpans(ScopeSpans&& from) noexcept : ScopeSpans(nullptr, ::std::move(from)) {}
  inline ScopeSpans& operator=(const ScopeSpans& from) {
    CopyFrom(from);
    return *this;
  }
  inline ScopeSpans& operator=(ScopeSpans&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ScopeSpans& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<ScopeSpans>(&ScopeSpans_globals_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(ScopeSpans& a, ScopeSpans& b) { a.Swap(&b); }
  inline void Swap(ScopeSpans* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ScopeSpans* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ScopeSpans* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ScopeSpans>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ScopeSpans& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ScopeSpans& from) { ScopeSpans::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ScopeSpans* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.ScopeSpans"; }

  explicit ScopeSpans(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ScopeSpans(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ScopeSpans& from);
  ScopeSpans(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ScopeSpans&& from) noexcept
      : ScopeSpans(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kSpansFieldNumber = 2,
    kSchemaUrlFieldNumber = 3,
    kScopeFieldNumber = 1,
  };
  // repeated .opentelemetry.proto.trace.v1.Span spans = 2;
  [[nodiscard]] int spans_size()
      const;
  private:
  int _internal_spans_size() const;

  public:
  void clear_spans() ;
  [[nodiscard]] const ::opentelemetry::proto::trace::v1::Span& spans(int index) const;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::Span* PROTOBUF_NONNULL mutable_spans(int index);
  ::opentelemetry::proto::trace::v1::Span* PROTOBUF_NONNULL add_spans();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>&
  spans() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>* PROTOBUF_NONNULL
  mutable_spans();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>& _internal_spans() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>* PROTOBUF_NONNULL _internal_mutable_spans();

  public:
  // string schema_url = 3;
  void clear_schema_url() ;
  [[nodiscard]] const ::std::string& schema_url() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_schema_url(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_schema_url();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_schema_url();
  void set_allocated_schema_url(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_schema_url() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_schema_url(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_schema_url();

  public:
  // .opentelemetry.proto.common.v1.InstrumentationScope scope = 1;
  [[nodiscard]] bool has_scope()
      const;
  void clear_scope() ;
  [[nodiscard]] const ::opentelemetry::proto::common::v1::InstrumentationScope& scope() const;
  [[nodiscard]] ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE release_scope();
  ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NONNULL mutable_scope();
  void set_allocated_scope(::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_scope(::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE value);
  ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE unsafe_arena_release_scope();

  private:
  const ::opentelemetry::proto::common::v1::InstrumentationScope& _internal_scope() const;
  ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NONNULL _internal_mutable_scope();

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.ScopeSpans)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 3,
                          2, 58,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ScopeSpans& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::trace::v1::Span > spans_;
    ::google::protobuf::internal::ArenaStringPtr schema_url_;
    ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE scope_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ResourceSpans final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.ResourceSpans) */ {
 public:
  inline ResourceSpans() : ResourceSpans(nullptr) {}
  ~ResourceSpans() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ResourceSpans* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ResourceSpans));
  }
#endif

  template <typename = void>
  explicit constexpr ResourceSpans(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline ResourceSpans(const ResourceSpans& from) : ResourceSpans(nullptr, from) {}
  inline ResourceSpans(ResourceSpans&& from) noexcept : ResourceSpans(nullptr, ::std::move(from)) {}
  inline ResourceSpans& operator=(const ResourceSpans& from) {
    CopyFrom(from);
    return *this;
  }
  inline ResourceSpans& operator=(ResourceSpans&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ResourceSpans& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<ResourceSpans>(&ResourceSpans_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(ResourceSpans& a, ResourceSpans& b) { a.Swap(&b); }
  inline void Swap(ResourceSpans* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ResourceSpans* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ResourceSpans* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ResourceSpans>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ResourceSpans& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ResourceSpans& from) { ResourceSpans::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ResourceSpans* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.ResourceSpans"; }

  explicit ResourceSpans(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ResourceSpans(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ResourceSpans& from);
  ResourceSpans(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ResourceSpans&& from) noexcept
      : ResourceSpans(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kScopeSpansFieldNumber = 2,
    kSchemaUrlFieldNumber = 3,
    kResourceFieldNumber = 1,
  };
  // repeated .opentelemetry.proto.trace.v1.ScopeSpans scope_spans = 2;
  [[nodiscard]] int scope_spans_size()
      const;
  private:
  int _internal_scope_spans_size() const;

  public:
  void clear_scope_spans() ;
  [[nodiscard]] const ::opentelemetry::proto::trace::v1::ScopeSpans& scope_spans(int index) const;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::ScopeSpans* PROTOBUF_NONNULL mutable_scope_spans(int index);
  ::opentelemetry::proto::trace::v1::ScopeSpans* PROTOBUF_NONNULL add_scope_spans();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>&
  scope_spans() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>* PROTOBUF_NONNULL
  mutable_scope_spans();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>& _internal_scope_spans() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>* PROTOBUF_NONNULL _internal_mutable_scope_spans();

  public:
  // string schema_url = 3;
  void clear_schema_url() ;
  [[nodiscard]] const ::std::string& schema_url() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_schema_url(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_schema_url();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_schema_url();
  void set_allocated_schema_url(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_schema_url() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_schema_url(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_schema_url();

  public:
  // .opentelemetry.proto.resource.v1.Resource resource = 1;
  [[nodiscard]] bool has_resource()
      const;
  void clear_resource() ;
  [[nodiscard]] const ::opentelemetry::proto::resource::v1::Resource& resource() const;
  [[nodiscard]] ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE release_resource();
  ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NONNULL mutable_resource();
  void set_allocated_resource(::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_resource(::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE value);
  ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE unsafe_arena_release_resource();

  private:
  const ::opentelemetry::proto::resource::v1::Resource& _internal_resource() const;
  ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NONNULL _internal_mutable_resource();

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.ResourceSpans)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 3,
                          2, 61,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ResourceSpans& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::trace::v1::ScopeSpans > scope_spans_;
    ::google::protobuf::internal::ArenaStringPtr schema_url_;
    ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE resource_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED TracesData final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:opentelemetry.proto.trace.v1.TracesData) */ {
 public:
  inline TracesData() : TracesData(nullptr) {}
  ~TracesData() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(TracesData* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(TracesData));
  }
#endif

  template <typename = void>
  explicit constexpr TracesData(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline TracesData(const TracesData& from) : TracesData(nullptr, from) {}
  inline TracesData(TracesData&& from) noexcept : TracesData(nullptr, ::std::move(from)) {}
  inline TracesData& operator=(const TracesData& from) {
    CopyFrom(from);
    return *this;
  }
  inline TracesData& operator=(TracesData&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const TracesData& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<TracesData>(&TracesData_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(TracesData& a, TracesData& b) { a.Swap(&b); }
  inline void Swap(TracesData* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(TracesData* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] TracesData* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<TracesData>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const TracesData& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const TracesData& from) { TracesData::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(TracesData* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "opentelemetry.proto.trace.v1.TracesData"; }

  explicit TracesData(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  TracesData(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const TracesData& from);
  TracesData(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, TracesData&& from) noexcept
      : TracesData(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kResourceSpansFieldNumber = 1,
  };
  // repeated .opentelemetry.proto.trace.v1.ResourceSpans resource_spans = 1;
  [[nodiscard]] int resource_spans_size()
      const;
  private:
  int _internal_resource_spans_size() const;

  public:
  void clear_resource_spans() ;
  [[nodiscard]] const ::opentelemetry::proto::trace::v1::ResourceSpans& resource_spans(int index) const;
  [[nodiscard]] ::opentelemetry::proto::trace::v1::ResourceSpans* PROTOBUF_NONNULL mutable_resource_spans(int index);
  ::opentelemetry::proto::trace::v1::ResourceSpans* PROTOBUF_NONNULL add_resource_spans();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>&
  resource_spans() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>* PROTOBUF_NONNULL
  mutable_resource_spans();

  private:
  const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>& _internal_resource_spans() const;
  ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>* PROTOBUF_NONNULL _internal_mutable_resource_spans();

  public:
  // @@protoc_insertion_point(class_scope:opentelemetry.proto.trace.v1.TracesData)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<0, 1,
                          1, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const TracesData& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::opentelemetry::proto::trace::v1::ResourceSpans > resource_spans_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// TracesData

// repeated .opentelemetry.proto.trace.v1.ResourceSpans resource_spans = 1;
inline int TracesData::_internal_resource_spans_size() const {
  return _internal_resource_spans().size();
}
inline int TracesData::resource_spans_size() const {
  return _internal_resource_spans_size();
}
inline void TracesData::clear_resource_spans() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.resource_spans_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::opentelemetry::proto::trace::v1::ResourceSpans& TracesData::resource_spans(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.TracesData.resource_spans)
  return _internal_resource_spans().Get(index);
}
inline ::opentelemetry::proto::trace::v1::ResourceSpans* PROTOBUF_NONNULL TracesData::mutable_resource_spans(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.TracesData.resource_spans)
  return _internal_mutable_resource_spans()->Mutable(index);
}
inline ::opentelemetry::proto::trace::v1::ResourceSpans* PROTOBUF_NONNULL TracesData::add_resource_spans()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::trace::v1::ResourceSpans* _add =
      _internal_mutable_resource_spans()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.TracesData.resource_spans)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>& TracesData::resource_spans() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.TracesData.resource_spans)
  return _internal_resource_spans();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>* PROTOBUF_NONNULL
TracesData::mutable_resource_spans() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.TracesData.resource_spans)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_resource_spans();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>&
TracesData::_internal_resource_spans() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.resource_spans_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ResourceSpans>* PROTOBUF_NONNULL
TracesData::_internal_mutable_resource_spans() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.resource_spans_;
}

// -------------------------------------------------------------------

// ResourceSpans

// .opentelemetry.proto.resource.v1.Resource resource = 1;
inline bool ResourceSpans::has_resource() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  PROTOBUF_ASSUME(!value || _impl_.resource_ != nullptr);
  return value;
}
inline const ::opentelemetry::proto::resource::v1::Resource& ResourceSpans::_internal_resource() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::opentelemetry::proto::resource::v1::Resource* p = _impl_.resource_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::opentelemetry::proto::resource::v1::Resource>(&::opentelemetry::proto::resource::v1::Resource_globals_);
}
inline const ::opentelemetry::proto::resource::v1::Resource& ResourceSpans::resource() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.ResourceSpans.resource)
  return _internal_resource();
}
inline void ResourceSpans::unsafe_arena_set_allocated_resource(
    ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.resource_);
  }
  _impl_.resource_ = reinterpret_cast<::opentelemetry::proto::resource::v1::Resource*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opentelemetry.proto.trace.v1.ResourceSpans.resource)
}
inline ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE ResourceSpans::release_resource() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::opentelemetry::proto::resource::v1::Resource* released = _impl_.resource_;
  _impl_.resource_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE ResourceSpans::unsafe_arena_release_resource() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.ResourceSpans.resource)

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::opentelemetry::proto::resource::v1::Resource* temp = _impl_.resource_;
  _impl_.resource_ = nullptr;
  return temp;
}
inline ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NONNULL ResourceSpans::_internal_mutable_resource() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.resource_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::opentelemetry::proto::resource::v1::Resource>(GetArena());
    _impl_.resource_ = reinterpret_cast<::opentelemetry::proto::resource::v1::Resource*>(p);
  }
  return _impl_.resource_;
}
inline ::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NONNULL ResourceSpans::mutable_resource()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::opentelemetry::proto::resource::v1::Resource* _msg = _internal_mutable_resource();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.ResourceSpans.resource)
  return _msg;
}
inline void ResourceSpans::set_allocated_resource(::opentelemetry::proto::resource::v1::Resource* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.resource_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }

  _impl_.resource_ = reinterpret_cast<::opentelemetry::proto::resource::v1::Resource*>(value);
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.ResourceSpans.resource)
}

// repeated .opentelemetry.proto.trace.v1.ScopeSpans scope_spans = 2;
inline int ResourceSpans::_internal_scope_spans_size() const {
  return _internal_scope_spans().size();
}
inline int ResourceSpans::scope_spans_size() const {
  return _internal_scope_spans_size();
}
inline void ResourceSpans::clear_scope_spans() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.scope_spans_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::opentelemetry::proto::trace::v1::ScopeSpans& ResourceSpans::scope_spans(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.ResourceSpans.scope_spans)
  return _internal_scope_spans().Get(index);
}
inline ::opentelemetry::proto::trace::v1::ScopeSpans* PROTOBUF_NONNULL ResourceSpans::mutable_scope_spans(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.ResourceSpans.scope_spans)
  return _internal_mutable_scope_spans()->Mutable(index);
}
inline ::opentelemetry::proto::trace::v1::ScopeSpans* PROTOBUF_NONNULL ResourceSpans::add_scope_spans()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::trace::v1::ScopeSpans* _add =
      _internal_mutable_scope_spans()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.ResourceSpans.scope_spans)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>& ResourceSpans::scope_spans() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.ResourceSpans.scope_spans)
  return _internal_scope_spans();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>* PROTOBUF_NONNULL
ResourceSpans::mutable_scope_spans() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.ResourceSpans.scope_spans)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_scope_spans();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>&
ResourceSpans::_internal_scope_spans() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.scope_spans_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::ScopeSpans>* PROTOBUF_NONNULL
ResourceSpans::_internal_mutable_scope_spans() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.scope_spans_;
}

// string schema_url = 3;
inline void ResourceSpans::clear_schema_url() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.schema_url_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& ResourceSpans::schema_url() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.ResourceSpans.schema_url)
  return _internal_schema_url();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void ResourceSpans::set_schema_url(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.schema_url_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.ResourceSpans.schema_url)
}
inline ::std::string* PROTOBUF_NONNULL ResourceSpans::mutable_schema_url()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_schema_url();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.ResourceSpans.schema_url)
  return _s;
}
inline const ::std::string& ResourceSpans::_internal_schema_url() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.schema_url_.Get();
}
inline void ResourceSpans::_internal_set_schema_url(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.schema_url_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL ResourceSpans::_internal_mutable_schema_url() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.schema_url_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE ResourceSpans::release_schema_url() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.ResourceSpans.schema_url)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.schema_url_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.schema_url_.Set("", GetArena());
  }
  return released;
}
inline void ResourceSpans::set_allocated_schema_url(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.schema_url_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.schema_url_.IsDefault()) {
    _impl_.schema_url_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.ResourceSpans.schema_url)
}

// -------------------------------------------------------------------

// ScopeSpans

// .opentelemetry.proto.common.v1.InstrumentationScope scope = 1;
inline bool ScopeSpans::has_scope() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  PROTOBUF_ASSUME(!value || _impl_.scope_ != nullptr);
  return value;
}
inline const ::opentelemetry::proto::common::v1::InstrumentationScope& ScopeSpans::_internal_scope() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::opentelemetry::proto::common::v1::InstrumentationScope* p = _impl_.scope_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::opentelemetry::proto::common::v1::InstrumentationScope>(&::opentelemetry::proto::common::v1::InstrumentationScope_globals_);
}
inline const ::opentelemetry::proto::common::v1::InstrumentationScope& ScopeSpans::scope() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.ScopeSpans.scope)
  return _internal_scope();
}
inline void ScopeSpans::unsafe_arena_set_allocated_scope(
    ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.scope_);
  }
  _impl_.scope_ = reinterpret_cast<::opentelemetry::proto::common::v1::InstrumentationScope*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opentelemetry.proto.trace.v1.ScopeSpans.scope)
}
inline ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE ScopeSpans::release_scope() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::opentelemetry::proto::common::v1::InstrumentationScope* released = _impl_.scope_;
  _impl_.scope_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE ScopeSpans::unsafe_arena_release_scope() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.ScopeSpans.scope)

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::opentelemetry::proto::common::v1::InstrumentationScope* temp = _impl_.scope_;
  _impl_.scope_ = nullptr;
  return temp;
}
inline ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NONNULL ScopeSpans::_internal_mutable_scope() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.scope_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::opentelemetry::proto::common::v1::InstrumentationScope>(GetArena());
    _impl_.scope_ = reinterpret_cast<::opentelemetry::proto::common::v1::InstrumentationScope*>(p);
  }
  return _impl_.scope_;
}
inline ::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NONNULL ScopeSpans::mutable_scope()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::opentelemetry::proto::common::v1::InstrumentationScope* _msg = _internal_mutable_scope();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.ScopeSpans.scope)
  return _msg;
}
inline void ScopeSpans::set_allocated_scope(::opentelemetry::proto::common::v1::InstrumentationScope* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.scope_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }

  _impl_.scope_ = reinterpret_cast<::opentelemetry::proto::common::v1::InstrumentationScope*>(value);
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.ScopeSpans.scope)
}

// repeated .opentelemetry.proto.trace.v1.Span spans = 2;
inline int ScopeSpans::_internal_spans_size() const {
  return _internal_spans().size();
}
inline int ScopeSpans::spans_size() const {
  return _internal_spans_size();
}
inline void ScopeSpans::clear_spans() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.spans_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::opentelemetry::proto::trace::v1::Span& ScopeSpans::spans(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.ScopeSpans.spans)
  return _internal_spans().Get(index);
}
inline ::opentelemetry::proto::trace::v1::Span* PROTOBUF_NONNULL ScopeSpans::mutable_spans(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.ScopeSpans.spans)
  return _internal_mutable_spans()->Mutable(index);
}
inline ::opentelemetry::proto::trace::v1::Span* PROTOBUF_NONNULL ScopeSpans::add_spans()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::trace::v1::Span* _add =
      _internal_mutable_spans()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.ScopeSpans.spans)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>& ScopeSpans::spans() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.ScopeSpans.spans)
  return _internal_spans();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>* PROTOBUF_NONNULL
ScopeSpans::mutable_spans() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.ScopeSpans.spans)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_spans();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>&
ScopeSpans::_internal_spans() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.spans_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span>* PROTOBUF_NONNULL
ScopeSpans::_internal_mutable_spans() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.spans_;
}

// string schema_url = 3;
inline void ScopeSpans::clear_schema_url() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.schema_url_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& ScopeSpans::schema_url() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.ScopeSpans.schema_url)
  return _internal_schema_url();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void ScopeSpans::set_schema_url(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.schema_url_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.ScopeSpans.schema_url)
}
inline ::std::string* PROTOBUF_NONNULL ScopeSpans::mutable_schema_url()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_schema_url();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.ScopeSpans.schema_url)
  return _s;
}
inline const ::std::string& ScopeSpans::_internal_schema_url() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.schema_url_.Get();
}
inline void ScopeSpans::_internal_set_schema_url(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.schema_url_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL ScopeSpans::_internal_mutable_schema_url() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.schema_url_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE ScopeSpans::release_schema_url() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.ScopeSpans.schema_url)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.schema_url_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.schema_url_.Set("", GetArena());
  }
  return released;
}
inline void ScopeSpans::set_allocated_schema_url(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.schema_url_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.schema_url_.IsDefault()) {
    _impl_.schema_url_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.ScopeSpans.schema_url)
}

// -------------------------------------------------------------------

// Span_Event

// fixed64 time_unix_nano = 1;
inline void Span_Event::clear_time_unix_nano() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.time_unix_nano_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline ::uint64_t Span_Event::time_unix_nano() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Event.time_unix_nano)
  return _internal_time_unix_nano();
}
inline void Span_Event::set_time_unix_nano(::uint64_t value) {
  _internal_set_time_unix_nano(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Event.time_unix_nano)
}
inline ::uint64_t Span_Event::_internal_time_unix_nano() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.time_unix_nano_;
}
inline void Span_Event::_internal_set_time_unix_nano(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.time_unix_nano_ = value;
}

// string name = 2;
inline void Span_Event::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& Span_Event::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Event.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span_Event::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Event.name)
}
inline ::std::string* PROTOBUF_NONNULL Span_Event::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.Event.name)
  return _s;
}
inline const ::std::string& Span_Event::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void Span_Event::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span_Event::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span_Event::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.Event.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void Span_Event::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.Event.name)
}

// repeated .opentelemetry.proto.common.v1.KeyValue attributes = 3;
inline int Span_Event::_internal_attributes_size() const {
  return _internal_attributes().size();
}
inline int Span_Event::attributes_size() const {
  return _internal_attributes_size();
}
inline const ::opentelemetry::proto::common::v1::KeyValue& Span_Event::attributes(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Event.attributes)
  return _internal_attributes().Get(index);
}
inline ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL Span_Event::mutable_attributes(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.Event.attributes)
  return _internal_mutable_attributes()->Mutable(index);
}
inline ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL Span_Event::add_attributes()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::common::v1::KeyValue* _add =
      _internal_mutable_attributes()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.Span.Event.attributes)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>& Span_Event::attributes() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.Span.Event.attributes)
  return _internal_attributes();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
Span_Event::mutable_attributes() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.Span.Event.attributes)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_attributes();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>&
Span_Event::_internal_attributes() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.attributes_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
Span_Event::_internal_mutable_attributes() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.attributes_;
}

// uint32 dropped_attributes_count = 4;
inline void Span_Event::clear_dropped_attributes_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_attributes_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline ::uint32_t Span_Event::dropped_attributes_count() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Event.dropped_attributes_count)
  return _internal_dropped_attributes_count();
}
inline void Span_Event::set_dropped_attributes_count(::uint32_t value) {
  _internal_set_dropped_attributes_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Event.dropped_attributes_count)
}
inline ::uint32_t Span_Event::_internal_dropped_attributes_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dropped_attributes_count_;
}
inline void Span_Event::_internal_set_dropped_attributes_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_attributes_count_ = value;
}

// -------------------------------------------------------------------

// Span_Link

// bytes trace_id = 1;
inline void Span_Link::clear_trace_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& Span_Link::trace_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Link.trace_id)
  return _internal_trace_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span_Link::set_trace_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.trace_id_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Link.trace_id)
}
inline ::std::string* PROTOBUF_NONNULL Span_Link::mutable_trace_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_trace_id();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.Link.trace_id)
  return _s;
}
inline const ::std::string& Span_Link::_internal_trace_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.trace_id_.Get();
}
inline void Span_Link::_internal_set_trace_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span_Link::_internal_mutable_trace_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.trace_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span_Link::release_trace_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.Link.trace_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.trace_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.trace_id_.Set("", GetArena());
  }
  return released;
}
inline void Span_Link::set_allocated_trace_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.trace_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.trace_id_.IsDefault()) {
    _impl_.trace_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.Link.trace_id)
}

// bytes span_id = 2;
inline void Span_Link::clear_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.span_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline const ::std::string& Span_Link::span_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Link.span_id)
  return _internal_span_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span_Link::set_span_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  _impl_.span_id_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Link.span_id)
}
inline ::std::string* PROTOBUF_NONNULL Span_Link::mutable_span_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::std::string* _s = _internal_mutable_span_id();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.Link.span_id)
  return _s;
}
inline const ::std::string& Span_Link::_internal_span_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.span_id_.Get();
}
inline void Span_Link::_internal_set_span_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.span_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span_Link::_internal_mutable_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.span_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span_Link::release_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.Link.span_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000004U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  auto* released = _impl_.span_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.span_id_.Set("", GetArena());
  }
  return released;
}
inline void Span_Link::set_allocated_span_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  _impl_.span_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.span_id_.IsDefault()) {
    _impl_.span_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.Link.span_id)
}

// string trace_state = 3;
inline void Span_Link::clear_trace_state() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_state_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline const ::std::string& Span_Link::trace_state() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Link.trace_state)
  return _internal_trace_state();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span_Link::set_trace_state(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  _impl_.trace_state_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Link.trace_state)
}
inline ::std::string* PROTOBUF_NONNULL Span_Link::mutable_trace_state()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::std::string* _s = _internal_mutable_trace_state();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.Link.trace_state)
  return _s;
}
inline const ::std::string& Span_Link::_internal_trace_state() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.trace_state_.Get();
}
inline void Span_Link::_internal_set_trace_state(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_state_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span_Link::_internal_mutable_trace_state() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.trace_state_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span_Link::release_trace_state() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.Link.trace_state)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000008U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  auto* released = _impl_.trace_state_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.trace_state_.Set("", GetArena());
  }
  return released;
}
inline void Span_Link::set_allocated_trace_state(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  _impl_.trace_state_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.trace_state_.IsDefault()) {
    _impl_.trace_state_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.Link.trace_state)
}

// repeated .opentelemetry.proto.common.v1.KeyValue attributes = 4;
inline int Span_Link::_internal_attributes_size() const {
  return _internal_attributes().size();
}
inline int Span_Link::attributes_size() const {
  return _internal_attributes_size();
}
inline const ::opentelemetry::proto::common::v1::KeyValue& Span_Link::attributes(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Link.attributes)
  return _internal_attributes().Get(index);
}
inline ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL Span_Link::mutable_attributes(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.Link.attributes)
  return _internal_mutable_attributes()->Mutable(index);
}
inline ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL Span_Link::add_attributes()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::common::v1::KeyValue* _add =
      _internal_mutable_attributes()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.Span.Link.attributes)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>& Span_Link::attributes() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.Span.Link.attributes)
  return _internal_attributes();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
Span_Link::mutable_attributes() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.Span.Link.attributes)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_attributes();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>&
Span_Link::_internal_attributes() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.attributes_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
Span_Link::_internal_mutable_attributes() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.attributes_;
}

// uint32 dropped_attributes_count = 5;
inline void Span_Link::clear_dropped_attributes_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_attributes_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline ::uint32_t Span_Link::dropped_attributes_count() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.Link.dropped_attributes_count)
  return _internal_dropped_attributes_count();
}
inline void Span_Link::set_dropped_attributes_count(::uint32_t value) {
  _internal_set_dropped_attributes_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.Link.dropped_attributes_count)
}
inline ::uint32_t Span_Link::_internal_dropped_attributes_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dropped_attributes_count_;
}
inline void Span_Link::_internal_set_dropped_attributes_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_attributes_count_ = value;
}

// -------------------------------------------------------------------

// Span

// bytes trace_id = 1;
inline void Span::clear_trace_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline const ::std::string& Span::trace_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.trace_id)
  return _internal_trace_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span::set_trace_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  _impl_.trace_id_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.trace_id)
}
inline ::std::string* PROTOBUF_NONNULL Span::mutable_trace_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::std::string* _s = _internal_mutable_trace_id();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.trace_id)
  return _s;
}
inline const ::std::string& Span::_internal_trace_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.trace_id_.Get();
}
inline void Span::_internal_set_trace_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span::_internal_mutable_trace_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.trace_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span::release_trace_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.trace_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000008U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  auto* released = _impl_.trace_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.trace_id_.Set("", GetArena());
  }
  return released;
}
inline void Span::set_allocated_trace_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  _impl_.trace_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.trace_id_.IsDefault()) {
    _impl_.trace_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.trace_id)
}

// bytes span_id = 2;
inline void Span::clear_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.span_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline const ::std::string& Span::span_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.span_id)
  return _internal_span_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span::set_span_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  _impl_.span_id_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.span_id)
}
inline ::std::string* PROTOBUF_NONNULL Span::mutable_span_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::std::string* _s = _internal_mutable_span_id();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.span_id)
  return _s;
}
inline const ::std::string& Span::_internal_span_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.span_id_.Get();
}
inline void Span::_internal_set_span_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.span_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span::_internal_mutable_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.span_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span::release_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.span_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000010U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  auto* released = _impl_.span_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.span_id_.Set("", GetArena());
  }
  return released;
}
inline void Span::set_allocated_span_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  }
  _impl_.span_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.span_id_.IsDefault()) {
    _impl_.span_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.span_id)
}

// string trace_state = 3;
inline void Span::clear_trace_state() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_state_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline const ::std::string& Span::trace_state() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.trace_state)
  return _internal_trace_state();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span::set_trace_state(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  _impl_.trace_state_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.trace_state)
}
inline ::std::string* PROTOBUF_NONNULL Span::mutable_trace_state()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  ::std::string* _s = _internal_mutable_trace_state();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.trace_state)
  return _s;
}
inline const ::std::string& Span::_internal_trace_state() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.trace_state_.Get();
}
inline void Span::_internal_set_trace_state(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trace_state_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span::_internal_mutable_trace_state() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.trace_state_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span::release_trace_state() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.trace_state)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000020U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  auto* released = _impl_.trace_state_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.trace_state_.Set("", GetArena());
  }
  return released;
}
inline void Span::set_allocated_trace_state(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  }
  _impl_.trace_state_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.trace_state_.IsDefault()) {
    _impl_.trace_state_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.trace_state)
}

// bytes parent_span_id = 4;
inline void Span::clear_parent_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.parent_span_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000040U);
}
inline const ::std::string& Span::parent_span_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.parent_span_id)
  return _internal_parent_span_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span::set_parent_span_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  _impl_.parent_span_id_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.parent_span_id)
}
inline ::std::string* PROTOBUF_NONNULL Span::mutable_parent_span_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  ::std::string* _s = _internal_mutable_parent_span_id();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.parent_span_id)
  return _s;
}
inline const ::std::string& Span::_internal_parent_span_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.parent_span_id_.Get();
}
inline void Span::_internal_set_parent_span_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.parent_span_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span::_internal_mutable_parent_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.parent_span_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span::release_parent_span_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.parent_span_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000040U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000040U);
  auto* released = _impl_.parent_span_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.parent_span_id_.Set("", GetArena());
  }
  return released;
}
inline void Span::set_allocated_parent_span_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000040U);
  }
  _impl_.parent_span_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.parent_span_id_.IsDefault()) {
    _impl_.parent_span_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.parent_span_id)
}

// string name = 5;
inline void Span::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000080U);
}
inline const ::std::string& Span::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Span::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000080U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.name)
}
inline ::std::string* PROTOBUF_NONNULL Span::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000080U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.name)
  return _s;
}
inline const ::std::string& Span::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void Span::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Span::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Span::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000080U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000080U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void Span::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000080U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000080U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.name)
}

// .opentelemetry.proto.trace.v1.Span.SpanKind kind = 6;
inline void Span::clear_kind() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.kind_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000800U);
}
inline ::opentelemetry::proto::trace::v1::Span_SpanKind Span::kind() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.kind)
  return _internal_kind();
}
inline void Span::set_kind(::opentelemetry::proto::trace::v1::Span_SpanKind value) {
  _internal_set_kind(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000800U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.kind)
}
inline ::opentelemetry::proto::trace::v1::Span_SpanKind Span::_internal_kind() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::opentelemetry::proto::trace::v1::Span_SpanKind>(_impl_.kind_);
}
inline void Span::_internal_set_kind(::opentelemetry::proto::trace::v1::Span_SpanKind value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.kind_ = value;
}

// fixed64 start_time_unix_nano = 7;
inline void Span::clear_start_time_unix_nano() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.start_time_unix_nano_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0], 0x00000200U);
}
inline ::uint64_t Span::start_time_unix_nano() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.start_time_unix_nano)
  return _internal_start_time_unix_nano();
}
inline void Span::set_start_time_unix_nano(::uint64_t value) {
  _internal_set_start_time_unix_nano(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000200U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.start_time_unix_nano)
}
inline ::uint64_t Span::_internal_start_time_unix_nano() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.start_time_unix_nano_;
}
inline void Span::_internal_set_start_time_unix_nano(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.start_time_unix_nano_ = value;
}

// fixed64 end_time_unix_nano = 8;
inline void Span::clear_end_time_unix_nano() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.end_time_unix_nano_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0], 0x00000400U);
}
inline ::uint64_t Span::end_time_unix_nano() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.end_time_unix_nano)
  return _internal_end_time_unix_nano();
}
inline void Span::set_end_time_unix_nano(::uint64_t value) {
  _internal_set_end_time_unix_nano(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000400U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.end_time_unix_nano)
}
inline ::uint64_t Span::_internal_end_time_unix_nano() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.end_time_unix_nano_;
}
inline void Span::_internal_set_end_time_unix_nano(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.end_time_unix_nano_ = value;
}

// repeated .opentelemetry.proto.common.v1.KeyValue attributes = 9;
inline int Span::_internal_attributes_size() const {
  return _internal_attributes().size();
}
inline int Span::attributes_size() const {
  return _internal_attributes_size();
}
inline const ::opentelemetry::proto::common::v1::KeyValue& Span::attributes(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.attributes)
  return _internal_attributes().Get(index);
}
inline ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL Span::mutable_attributes(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.attributes)
  return _internal_mutable_attributes()->Mutable(index);
}
inline ::opentelemetry::proto::common::v1::KeyValue* PROTOBUF_NONNULL Span::add_attributes()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::common::v1::KeyValue* _add =
      _internal_mutable_attributes()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.Span.attributes)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>& Span::attributes() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.Span.attributes)
  return _internal_attributes();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
Span::mutable_attributes() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.Span.attributes)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_attributes();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>&
Span::_internal_attributes() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.attributes_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::common::v1::KeyValue>* PROTOBUF_NONNULL
Span::_internal_mutable_attributes() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.attributes_;
}

// uint32 dropped_attributes_count = 10;
inline void Span::clear_dropped_attributes_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_attributes_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00001000U);
}
inline ::uint32_t Span::dropped_attributes_count() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.dropped_attributes_count)
  return _internal_dropped_attributes_count();
}
inline void Span::set_dropped_attributes_count(::uint32_t value) {
  _internal_set_dropped_attributes_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00001000U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.dropped_attributes_count)
}
inline ::uint32_t Span::_internal_dropped_attributes_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dropped_attributes_count_;
}
inline void Span::_internal_set_dropped_attributes_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_attributes_count_ = value;
}

// repeated .opentelemetry.proto.trace.v1.Span.Event events = 11;
inline int Span::_internal_events_size() const {
  return _internal_events().size();
}
inline int Span::events_size() const {
  return _internal_events_size();
}
inline void Span::clear_events() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.events_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::opentelemetry::proto::trace::v1::Span_Event& Span::events(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.events)
  return _internal_events().Get(index);
}
inline ::opentelemetry::proto::trace::v1::Span_Event* PROTOBUF_NONNULL Span::mutable_events(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.events)
  return _internal_mutable_events()->Mutable(index);
}
inline ::opentelemetry::proto::trace::v1::Span_Event* PROTOBUF_NONNULL Span::add_events()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::trace::v1::Span_Event* _add =
      _internal_mutable_events()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.Span.events)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>& Span::events() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.Span.events)
  return _internal_events();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>* PROTOBUF_NONNULL
Span::mutable_events() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.Span.events)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_events();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>&
Span::_internal_events() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.events_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Event>* PROTOBUF_NONNULL
Span::_internal_mutable_events() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.events_;
}

// uint32 dropped_events_count = 12;
inline void Span::clear_dropped_events_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_events_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00002000U);
}
inline ::uint32_t Span::dropped_events_count() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.dropped_events_count)
  return _internal_dropped_events_count();
}
inline void Span::set_dropped_events_count(::uint32_t value) {
  _internal_set_dropped_events_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00002000U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.dropped_events_count)
}
inline ::uint32_t Span::_internal_dropped_events_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dropped_events_count_;
}
inline void Span::_internal_set_dropped_events_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_events_count_ = value;
}

// repeated .opentelemetry.proto.trace.v1.Span.Link links = 13;
inline int Span::_internal_links_size() const {
  return _internal_links().size();
}
inline int Span::links_size() const {
  return _internal_links_size();
}
inline void Span::clear_links() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.links_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline const ::opentelemetry::proto::trace::v1::Span_Link& Span::links(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.links)
  return _internal_links().Get(index);
}
inline ::opentelemetry::proto::trace::v1::Span_Link* PROTOBUF_NONNULL Span::mutable_links(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.links)
  return _internal_mutable_links()->Mutable(index);
}
inline ::opentelemetry::proto::trace::v1::Span_Link* PROTOBUF_NONNULL Span::add_links()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::opentelemetry::proto::trace::v1::Span_Link* _add =
      _internal_mutable_links()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_add:opentelemetry.proto.trace.v1.Span.links)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>& Span::links() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:opentelemetry.proto.trace.v1.Span.links)
  return _internal_links();
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>* PROTOBUF_NONNULL
Span::mutable_links() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_mutable_list:opentelemetry.proto.trace.v1.Span.links)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_links();
}
inline const ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>&
Span::_internal_links() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.links_;
}
inline ::google::protobuf::RepeatedPtrField<::opentelemetry::proto::trace::v1::Span_Link>* PROTOBUF_NONNULL
Span::_internal_mutable_links() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.links_;
}

// uint32 dropped_links_count = 14;
inline void Span::clear_dropped_links_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_links_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00004000U);
}
inline ::uint32_t Span::dropped_links_count() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.dropped_links_count)
  return _internal_dropped_links_count();
}
inline void Span::set_dropped_links_count(::uint32_t value) {
  _internal_set_dropped_links_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00004000U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Span.dropped_links_count)
}
inline ::uint32_t Span::_internal_dropped_links_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dropped_links_count_;
}
inline void Span::_internal_set_dropped_links_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dropped_links_count_ = value;
}

// .opentelemetry.proto.trace.v1.Status status = 15;
inline bool Span::has_status() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000100U);
  PROTOBUF_ASSUME(!value || _impl_.status_ != nullptr);
  return value;
}
inline void Span::clear_status() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.status_ != nullptr) _impl_.status_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000100U);
}
inline const ::opentelemetry::proto::trace::v1::Status& Span::_internal_status() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::opentelemetry::proto::trace::v1::Status* p = _impl_.status_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::opentelemetry::proto::trace::v1::Status>(&::opentelemetry::proto::trace::v1::Status_globals_);
}
inline const ::opentelemetry::proto::trace::v1::Status& Span::status() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Span.status)
  return _internal_status();
}
inline void Span::unsafe_arena_set_allocated_status(
    ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.status_);
  }
  _impl_.status_ = reinterpret_cast<::opentelemetry::proto::trace::v1::Status*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000100U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000100U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:opentelemetry.proto.trace.v1.Span.status)
}
inline ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE Span::release_status() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000100U);
  ::opentelemetry::proto::trace::v1::Status* released = _impl_.status_;
  _impl_.status_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE Span::unsafe_arena_release_status() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Span.status)

  ClearHasBit(_impl_._has_bits_[0], 0x00000100U);
  ::opentelemetry::proto::trace::v1::Status* temp = _impl_.status_;
  _impl_.status_ = nullptr;
  return temp;
}
inline ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NONNULL Span::_internal_mutable_status() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.status_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::opentelemetry::proto::trace::v1::Status>(GetArena());
    _impl_.status_ = reinterpret_cast<::opentelemetry::proto::trace::v1::Status*>(p);
  }
  return _impl_.status_;
}
inline ::opentelemetry::proto::trace::v1::Status* PROTOBUF_NONNULL Span::mutable_status()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000100U);
  ::opentelemetry::proto::trace::v1::Status* _msg = _internal_mutable_status();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Span.status)
  return _msg;
}
inline void Span::set_allocated_status(::opentelemetry::proto::trace::v1::Status* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.status_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000100U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000100U);
  }

  _impl_.status_ = reinterpret_cast<::opentelemetry::proto::trace::v1::Status*>(value);
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Span.status)
}

// -------------------------------------------------------------------

// Status

// string message = 2;
inline void Status::clear_message() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.message_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& Status::message() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Status.message)
  return _internal_message();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Status::set_message(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.message_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Status.message)
}
inline ::std::string* PROTOBUF_NONNULL Status::mutable_message()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_message();
  // @@protoc_insertion_point(field_mutable:opentelemetry.proto.trace.v1.Status.message)
  return _s;
}
inline const ::std::string& Status::_internal_message() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.message_.Get();
}
inline void Status::_internal_set_message(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.message_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Status::_internal_mutable_message() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.message_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Status::release_message() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:opentelemetry.proto.trace.v1.Status.message)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.message_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.message_.Set("", GetArena());
  }
  return released;
}
inline void Status::set_allocated_message(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.message_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.message_.IsDefault()) {
    _impl_.message_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:opentelemetry.proto.trace.v1.Status.message)
}

// .opentelemetry.proto.trace.v1.Status.StatusCode code = 3;
inline void Status::clear_code() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.code_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline ::opentelemetry::proto::trace::v1::Status_StatusCode Status::code() const {
  // @@protoc_insertion_point(field_get:opentelemetry.proto.trace.v1.Status.code)
  return _internal_code();
}
inline void Status::set_code(::opentelemetry::proto::trace::v1::Status_StatusCode value) {
  _internal_set_code(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:opentelemetry.proto.trace.v1.Status.code)
}
inline ::opentelemetry::proto::trace::v1::Status_StatusCode Status::_internal_code() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::opentelemetry::proto::trace::v1::Status_StatusCode>(_impl_.code_);
}
inline void Status::_internal_set_code(::opentelemetry::proto::trace::v1::Status_StatusCode value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.code_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace trace
}  // namespace proto
}  // namespace opentelemetry


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::opentelemetry::proto::trace::v1::Span_SpanKind> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::opentelemetry::proto::trace::v1::Span_SpanKind>() {
  return ::opentelemetry::proto::trace::v1::Span_SpanKind_descriptor();
}
template <>
struct is_proto_enum<::opentelemetry::proto::trace::v1::Status_StatusCode> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::opentelemetry::proto::trace::v1::Status_StatusCode>() {
  return ::opentelemetry::proto::trace::v1::Status_StatusCode_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // opentelemetry_2fproto_2ftrace_2fv1_2ftrace_2eproto_2epb_2eh
